@@ -56,11 +56,11 @@ public:
     void saveConfig();
 
     QList<Row> m_rows;
-    FileMetaDataProvider *m_provider;
-    QGridLayout *m_gridLayout;
+    FileMetaDataProvider *m_provider = nullptr;
+    QGridLayout *m_gridLayout = nullptr;
 
-    MetadataFilter *m_filter;
-    WidgetFactory *m_widgetFactory;
+    MetadataFilter *m_filter = nullptr;
+    WidgetFactory *m_widgetFactory = nullptr;
 
     QMap<QString, bool> m_visibilityChanged;
     bool m_configureVisibleProperties = false;
@@ -71,8 +71,6 @@ private:
 
 FileMetaDataWidgetPrivate::FileMetaDataWidgetPrivate(FileMetaDataWidget *parent)
     : m_rows()
-    , m_provider(nullptr)
-    , m_gridLayout(nullptr)
     , q(parent)
 {
     m_filter = new MetadataFilter(q);
@@ -92,7 +90,7 @@ FileMetaDataWidgetPrivate::~FileMetaDataWidgetPrivate() = default;
 
 void FileMetaDataWidgetPrivate::deleteRows()
 {
-    for (const Row &row : qAsConst(m_rows)) {
+    for (const Row &row : std::as_const(m_rows)) {
         delete row.label;
         row.value->deleteLater();
         if (row.checkBox) {
@@ -105,7 +103,7 @@ void FileMetaDataWidgetPrivate::deleteRows()
 
 QLabel *FileMetaDataWidgetPrivate::createLabel(const QString &key, const QString &itemLabel, FileMetaDataWidget *parent)
 {
-    QLabel *label = new QLabel(itemLabel + QLatin1Char(':'), parent);
+    auto label = new QLabel(itemLabel + QLatin1Char(':'), parent);
     label->setTextInteractionFlags(Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard);
     label->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
     label->setForegroundRole(parent->foregroundRole());
@@ -233,7 +231,7 @@ QStringList FileMetaDataWidgetPrivate::sortedKeys(const QVariantMap &data) const
         QString key = m_provider->group(propName);
         key += m_provider->label(propName);
 
-        map.insertMulti(key, propName);
+        map.insert(key, propName);
         ++hashIt;
     }
 
@@ -316,7 +314,7 @@ QSize FileMetaDataWidget::sizeHint() const
     int leftWidthMax = 0;
     int rightWidthMax = 0;
     int rightWidthAverage = 0;
-    for (const FileMetaDataWidgetPrivate::Row &row : qAsConst(d->m_rows)) {
+    for (const FileMetaDataWidgetPrivate::Row &row : std::as_const(d->m_rows)) {
         const QWidget *valueWidget = row.value;
         const int rightWidth = valueWidget->sizeHint().width();
         rightWidthAverage += rightWidth;
@@ -341,16 +339,16 @@ QSize FileMetaDataWidget::sizeHint() const
     }
 
     // Based on the available width calculate the required height
-    int height = d->m_gridLayout->margin() * 2 + d->m_gridLayout->spacing() * (d->m_rows.count() - 1);
-    for (const FileMetaDataWidgetPrivate::Row &row : qAsConst(d->m_rows)) {
+    int height = getMargin() * 2 + d->m_gridLayout->spacing() * (d->m_rows.count() - 1);
+    for (const FileMetaDataWidgetPrivate::Row &row : std::as_const(d->m_rows)) {
         const QWidget *valueWidget = row.value;
         const int rowHeight = qMax(row.label->heightForWidth(leftWidthMax), valueWidget->heightForWidth(rightWidthMax));
         height += rowHeight;
     }
 
-    const int width = d->m_gridLayout->margin() * 2 + leftWidthMax + d->m_gridLayout->spacing() + rightWidthMax;
+    const int width = getMargin() * 2 + leftWidthMax + d->m_gridLayout->spacing() + rightWidthMax;
 
-    return QSize(width, height);
+    return QSize{width, height};
 }
 
 void FileMetaDataWidget::setConfigurationMode(ConfigurationMode mode)
@@ -367,4 +365,15 @@ void FileMetaDataWidget::setConfigurationMode(ConfigurationMode mode)
     d->slotLoadingFinished();
 }
 
+int FileMetaDataWidget::getMargin() const
+{
+    int left, top, right, bottom;
+    d->m_gridLayout->getContentsMargins(&left, &top, &right, &bottom);
+    if (left == top && top == right && right == bottom) {
+        return left;
+    } else {
+        return -1;
+    }
+}
+
 #include "moc_filemetadatawidget.cpp"
